@@ -24,6 +24,7 @@ extern "C" {
 
 #include <QSslSocket>
 
+#include "kio_version.h"
 #include <KTcpSocket>
 
 #include <kio/slaveinterface.h>
@@ -45,20 +46,29 @@ extern "C" {
 #define MAX_RESPONSE_LEN 512
 #define MAX_COMMANDS 10
 
+// Pseudo plugin class to embed meta data
+class KIOPluginForMetaData : public QObject
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.pop3" FILE "pop3.json")
+};
+
 extern "C" {
 int Q_DECL_EXPORT kdemain(int argc, char **argv);
 }
 
 using namespace KIO;
 
-static const sasl_callback_t callbacks[] = {{SASL_CB_ECHOPROMPT, nullptr, nullptr},
-                                            {SASL_CB_NOECHOPROMPT, nullptr, nullptr},
-                                            {SASL_CB_GETREALM, nullptr, nullptr},
-                                            {SASL_CB_USER, nullptr, nullptr},
-                                            {SASL_CB_AUTHNAME, nullptr, nullptr},
-                                            {SASL_CB_PASS, nullptr, nullptr},
-                                            {SASL_CB_CANON_USER, nullptr, nullptr},
-                                            {SASL_CB_LIST_END, nullptr, nullptr}};
+static const sasl_callback_t callbacks[] = {
+    {SASL_CB_ECHOPROMPT, nullptr, nullptr},
+    {SASL_CB_NOECHOPROMPT, nullptr, nullptr},
+    {SASL_CB_GETREALM, nullptr, nullptr},
+    {SASL_CB_USER, nullptr, nullptr},
+    {SASL_CB_AUTHNAME, nullptr, nullptr},
+    {SASL_CB_PASS, nullptr, nullptr},
+    {SASL_CB_CANON_USER, nullptr, nullptr},
+    {SASL_CB_LIST_END, nullptr, nullptr},
+};
 
 int kdemain(int argc, char **argv)
 {
@@ -365,7 +375,7 @@ int POP3Protocol::loginAPOP(const char *challenge, KIO::AuthInfo &ai)
 bool POP3Protocol::saslInteract(void *in, AuthInfo &ai)
 {
     qCDebug(POP3_LOG);
-    auto *interact = (sasl_interact_t *)in;
+    auto interact = (sasl_interact_t *)in;
 
     // some mechanisms do not require username && pass, so don't need a popup
     // window for getting this info
@@ -605,7 +615,11 @@ bool POP3Protocol::pop3_open()
         // use QSslSocket internally
         QNetworkProxy proxy;
         proxy.setType(QNetworkProxy::NoProxy);
+        //#if KIO_VERSION < QT_VERSION_CHECK(5, 83, 0)
         if (auto sock = qobject_cast<QSslSocket *>(socket())) {
+            //#else
+            //        if (auto sock = qobject_cast<QSslSocket *>(tcpSocket())) {
+            //#endif
             sock->setProxy(proxy);
         } else {
             qCWarning(POP3_LOG) << "no socket, cannot set no proxy";
@@ -1151,3 +1165,5 @@ void POP3Protocol::del(const QUrl &url, bool /*isfile */)
     qCDebug(POP3_LOG) << "Path:" << _path;
     finished();
 }
+
+#include "pop3.moc"
