@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef EWSGETFOLDERREQUEST_H
-#define EWSGETFOLDERREQUEST_H
+#pragma once
 
 #include "ewsfolder.h"
 #include "ewsfoldershape.h"
@@ -54,4 +53,3 @@ private:
     QList<Response> mResponses;
 };
 
-#endif
