@@ -49,8 +49,7 @@ void EwsGetStreamingEventsRequest::start()
 
     endSoapDocument(writer);
 
-    qCDebugNC(EWSCLI_REQUEST_LOG) << QStringLiteral("Starting GetStreamingEvents request (subId: %1, timeout: %2)")
-        .arg(ewsHash(mSubscriptionId)).arg(mTimeout);
+    qCDebugNC(EWSCLI_REQUEST_LOG) << QStringLiteral("Starting GetStreamingEvents request (subId: %1, timeout: %2)").arg(ewsHash(mSubscriptionId)).arg(mTimeout);
 
     qCDebug(EWSCLI_PROTO_LOG) << reqString;
 
@@ -61,7 +60,7 @@ void EwsGetStreamingEventsRequest::start()
 
 void EwsGetStreamingEventsRequest::requestData(KIO::Job *job, const QByteArray &data)
 {
-    Q_UNUSED(job);
+    Q_UNUSED(job)
 
     mRespTimer.stop();
     qCDebug(EWSCLI_PROTO_LOG) << "data" << job << data;
