@@ -29,25 +29,29 @@ static const QString dayOfWeekNames[] = {
 };
 Q_CONSTEXPR unsigned dayOfWeekNameCount = sizeof(dayOfWeekNames) / sizeof(dayOfWeekNames[0]);
 
-static const QString dayOfWeekIndexNames[] = {QStringLiteral("First"),
-                                              QStringLiteral("Second"),
-                                              QStringLiteral("Third"),
-                                              QStringLiteral("Fourth"),
-                                              QStringLiteral("Last")};
+static const QString dayOfWeekIndexNames[] = {
+    QStringLiteral("First"),
+    QStringLiteral("Second"),
+    QStringLiteral("Third"),
+    QStringLiteral("Fourth"),
+    QStringLiteral("Last"),
+};
 Q_CONSTEXPR unsigned dayOfWeekIndexNameCount = sizeof(dayOfWeekIndexNames) / sizeof(dayOfWeekIndexNames[0]);
 
-static const QString monthNames[] = {QStringLiteral("January"),
-                                     QStringLiteral("February"),
-                                     QStringLiteral("March"),
-                                     QStringLiteral("April"),
-                                     QStringLiteral("May"),
-                                     QStringLiteral("June"),
-                                     QStringLiteral("July"),
-                                     QStringLiteral("August"),
-                                     QStringLiteral("September"),
-                                     QStringLiteral("October"),
-                                     QStringLiteral("November"),
-                                     QStringLiteral("December")};
+static const QString monthNames[] = {
+    QStringLiteral("January"),
+    QStringLiteral("February"),
+    QStringLiteral("March"),
+    QStringLiteral("April"),
+    QStringLiteral("May"),
+    QStringLiteral("June"),
+    QStringLiteral("July"),
+    QStringLiteral("August"),
+    QStringLiteral("September"),
+    QStringLiteral("October"),
+    QStringLiteral("November"),
+    QStringLiteral("December"),
+};
 Q_CONSTEXPR unsigned monthNameCount = sizeof(monthNames) / sizeof(monthNames[0]);
 
 EwsRecurrence::EwsRecurrence()
