@@ -4,10 +4,9 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef EWSTYPES_H
-#define EWSTYPES_H
+#pragma once
 
-#include <QString>
+class QString;
 #include <QVector>
 
 extern const QString soapEnvNsUri;
@@ -476,4 +475,3 @@ inline bool isEwsMessageItemType(EwsItemType type)
 
 extern const QVector<QString> ewsItemTypeNames;
 
-#endif
