@@ -250,7 +250,7 @@ void EwsFetchFoldersJobPrivate::processRemoteFolders()
          * which will cause the parent->child relationship to be broken. This happens because the
          * collection object holds a copy of the parent collection object. An update to that
          * object in the list will not be visible in the copy inside of the child object. */
-        EwsId parentId = folder[EwsFolderFieldParentFolderId].value<EwsId>();
+        auto parentId = folder[EwsFolderFieldParentFolderId].value<EwsId>();
         mParentMap.insert(parentId.id(), c.remoteId());
     }
 }
@@ -308,7 +308,7 @@ Collection EwsFetchFoldersJobPrivate::createFolderCollection(const EwsFolder &fo
     }
     collection.setContentMimeTypes(mimeTypes);
     Collection::Rights colRights;
-    EwsEffectiveRights ewsRights = folder[EwsFolderFieldEffectiveRights].value<EwsEffectiveRights>();
+    auto ewsRights = folder[EwsFolderFieldEffectiveRights].value<EwsEffectiveRights>();
     // FIXME: For now full read/write support is only implemented for e-mail. In order to avoid
     // potential problems block write access to all other folder types.
     if (folder.type() == EwsFolderTypeMail) {
@@ -326,7 +326,7 @@ Collection EwsFetchFoldersJobPrivate::createFolderCollection(const EwsFolder &fo
         }
     }
     collection.setRights(colRights);
-    EwsId id = folder[EwsFolderFieldFolderId].value<EwsId>();
+    auto id = folder[EwsFolderFieldFolderId].value<EwsId>();
     collection.setRemoteId(id.id());
     collection.setRemoteRevision(id.changeKey());
 
