@@ -24,7 +24,8 @@
 
 #include <chrono>
 
-namespace {
+namespace
+{
 // RFC2177 says clients should restart IDLE every 29 minutes, as
 // servers MAY consider clients inactive after 30 minutes.
 // TODO: Make configurable to support less RF-conformant servers
@@ -106,7 +107,7 @@ void ImapIdleManager::startIdle()
 {
     const auto idleMailBox = m_state->mailBoxForCollection(m_state->collection());
     if (m_session->selectedMailBox() != idleMailBox) {
-        auto *select = new KIMAP::SelectJob(m_session);
+        auto select = new KIMAP::SelectJob(m_session);
         select->setMailBox(idleMailBox);
         connect(select, &KIMAP::SelectJob::result, this, &ImapIdleManager::onSelectDone);
         select->start();
@@ -149,7 +150,7 @@ void ImapIdleManager::onPoolDisconnect()
 
 void ImapIdleManager::onSelectDone(KJob *job)
 {
-    auto *select = static_cast<KIMAP::SelectJob *>(job);
+    auto select = static_cast<KIMAP::SelectJob *>(job);
 
     m_lastMessageCount = select->messageCount();
     m_lastRecentCount = select->recentCount();
@@ -168,8 +169,8 @@ void ImapIdleManager::onIdleStopped()
 void ImapIdleManager::onStatsReceived(KIMAP::IdleJob *job, const QString &mailBox, int messageCount, int recentCount)
 {
     qCDebug(IMAPRESOURCE_LOG) << "IDLE stats received:" << job << mailBox << messageCount << recentCount;
-    qCDebug(IMAPRESOURCE_LOG) << "Cached information:" << m_state->collection().remoteId() << m_state->collection().id()
-                              << m_lastMessageCount << m_lastRecentCount;
+    qCDebug(IMAPRESOURCE_LOG) << "Cached information:" << m_state->collection().remoteId() << m_state->collection().id() << m_lastMessageCount
+                              << m_lastRecentCount;
 
     // It seems we're not in sync with the cache, resync is needed
     if (messageCount != m_lastMessageCount || recentCount != m_lastRecentCount) {
@@ -183,7 +184,7 @@ void ImapIdleManager::onStatsReceived(KIMAP::IdleJob *job, const QString &mailBo
 
 void ImapIdleManager::onFlagsChanged(KIMAP::IdleJob *job)
 {
-    Q_UNUSED(job);
+    Q_UNUSED(job)
     qCDebug(IMAPRESOURCE_LOG) << "IDLE flags changed in" << m_session->selectedMailBox();
     m_resource->synchronizeCollection(m_state->collection().id());
 }
