@@ -7,50 +7,52 @@
 
 #include "icalendar.h"
 #include "imip.h"
-#include "pimkolab_debug.h"
 #include "libkolab-version.h"
-#include <conversion/kcalconversion.h>
-#include <conversion/commonconversion.h>
-#include <mime/mimeutils.h>
-#include <kcalendarcore/event.h>
-#include <KCalendarCore/MemoryCalendar>
+#include "pimkolab_debug.h"
 #include <KCalendarCore/ICalFormat>
-#include <kmime/kmime_message.h>
+#include <KCalendarCore/MemoryCalendar>
 #include <KLocalizedString>
-#include <iostream>
 #include <QTimeZone>
+#include <conversion/commonconversion.h>
+#include <conversion/kcalconversion.h>
+#include <iostream>
+#include <kcalendarcore/event.h>
+#include <kmime/kmime_message.h>
+#include <mime/mimeutils.h>
 
-namespace Kolab {
+namespace Kolab
+{
 std::string toICal(const std::vector<Event> &events)
 {
     KCalendarCore::Calendar::Ptr calendar(new KCalendarCore::MemoryCalendar(Kolab::Conversion::getTimeSpec(true, std::string())));
     for (const Event &event : events) {
         KCalendarCore::Event::Ptr kcalEvent = Conversion::toKCalendarCore(event);
-        kcalEvent->setCreated(QDateTime::currentDateTimeUtc()); //sets dtstamp
+        kcalEvent->setCreated(QDateTime::currentDateTimeUtc()); // sets dtstamp
         calendar->addEvent(kcalEvent);
     }
     KCalendarCore::ICalFormat format;
     format.setApplication(QStringLiteral("libkolab"), QStringLiteral(LIBKOLAB_LIB_VERSION_STRING));
-//     qCDebug(PIMKOLAB_LOG) << format.createScheduleMessage(calendar->events().first(), KCalendarCore::iTIPRequest);
+    //     qCDebug(PIMKOLAB_LOG) << format.createScheduleMessage(calendar->events().first(), KCalendarCore::iTIPRequest);
 
     return Conversion::toStdString(format.toString(calendar));
 }
 
-std::vector< Event > fromICalEvents(const std::string &input)
+std::vector<Event> fromICalEvents(const std::string &input)
 {
     KCalendarCore::Calendar::Ptr calendar(new KCalendarCore::MemoryCalendar(Kolab::Conversion::getTimeSpec(true, std::string())));
     KCalendarCore::ICalFormat format;
     format.setApplication(QStringLiteral("libkolab"), QStringLiteral(LIBKOLAB_LIB_VERSION_STRING));
     format.fromString(calendar, Conversion::fromStdString(input));
     std::vector<Event> events;
-    foreach (const KCalendarCore::Event::Ptr &event, calendar->events()) {
+    const auto eventsList = calendar->events();
+    for (const KCalendarCore::Event::Ptr &event : eventsList) {
         events.push_back(Conversion::fromKCalendarCore(*event));
     }
     return events;
 }
 
 ITipHandler::ITipHandler()
-    :   mMethod(iTIPNoMethod)
+    : mMethod(iTIPNoMethod)
 {
 }
 
@@ -76,27 +78,27 @@ std::string ITipHandler::toITip(const Event &event, ITipHandler::ITipMethod meth
     if (m == KCalendarCore::iTIPNoMethod) {
         return std::string();
     }
-//     qCDebug(PIMKOLAB_LOG) << event.start().
-/* TODO
- * DTSTAMP is created
- * CREATED is current timestamp
- * LASTMODIFIED is lastModified
- *
- * Double check if that is correct.
- *
- * I think DTSTAMP should be the current timestamp, and CREATED should be the creation date.
- */
+    //     qCDebug(PIMKOLAB_LOG) << event.start().
+    /* TODO
+     * DTSTAMP is created
+     * CREATED is current timestamp
+     * LASTMODIFIED is lastModified
+     *
+     * Double check if that is correct.
+     *
+     * I think DTSTAMP should be the current timestamp, and CREATED should be the creation date.
+     */
     KCalendarCore::Event::Ptr e = Conversion::toKCalendarCore(event);
     return Conversion::toStdString(format.createScheduleMessage(e, m));
 }
 
-std::vector< Event > ITipHandler::fromITip(const std::string &string)
+std::vector<Event> ITipHandler::fromITip(const std::string &string)
 {
     KCalendarCore::Calendar::Ptr calendar(new KCalendarCore::MemoryCalendar(QTimeZone::utc()));
     KCalendarCore::ICalFormat format;
     KCalendarCore::ScheduleMessage::Ptr msg = format.parseScheduleMessage(calendar, Conversion::fromStdString(string));
     KCalendarCore::Event::Ptr event = msg->event().dynamicCast<KCalendarCore::Event>();
-    std::vector< Event > events;
+    std::vector<Event> events;
     events.push_back(Conversion::fromKCalendarCore(*event));
     mMethod = mapFromKCalendarCore(msg->method());
     return events;
@@ -110,15 +112,13 @@ ITipHandler::ITipMethod ITipHandler::method() const
 std::string ITipHandler::toIMip(const Event &event, ITipHandler::ITipMethod m, const std::string &from, bool bccMe) const
 {
     KCalendarCore::Event::Ptr e = Conversion::toKCalendarCore(event);
-//     e->recurrence()->addRDateTime(e->dtStart()); //FIXME The createScheduleMessage converts everything to utc without a recurrence.
+    //     e->recurrence()->addRDateTime(e->dtStart()); //FIXME The createScheduleMessage converts everything to utc without a recurrence.
     KCalendarCore::ICalFormat format;
     format.setApplication(QStringLiteral("libkolab"), QStringLiteral(LIBKOLAB_LIB_VERSION_STRING));
     KCalendarCore::iTIPMethod method = mapToKCalendarCore(m);
     const QString &messageText = format.createScheduleMessage(e, method);
-    //This code is mostly from MailScheduler::performTransaction
-    if (method == KCalendarCore::iTIPRequest
-        || method == KCalendarCore::iTIPCancel
-        || method == KCalendarCore::iTIPAdd
+    // This code is mostly from MailScheduler::performTransaction
+    if (method == KCalendarCore::iTIPRequest || method == KCalendarCore::iTIPCancel || method == KCalendarCore::iTIPAdd
         || method == KCalendarCore::iTIPDeclineCounter) {
         return Conversion::toStdString(QString::fromUtf8(mailAttendees(e, bccMe, messageText)));
     } else {
@@ -130,7 +130,7 @@ std::string ITipHandler::toIMip(const Event &event, ITipHandler::ITipMethod m, c
     }
 }
 
-std::vector< Event > ITipHandler::fromIMip(const std::string &input)
+std::vector<Event> ITipHandler::fromIMip(const std::string &input)
 {
     KMime::Message::Ptr msg = KMime::Message::Ptr(new KMime::Message);
     msg->setContent(Conversion::fromStdString(input).toUtf8());
@@ -140,7 +140,7 @@ std::vector< Event > ITipHandler::fromIMip(const std::string &input)
     KMime::Content *c = Kolab::Mime::findContentByType(msg, "text/calendar");
     if (!c) {
         qCWarning(PIMKOLAB_LOG) << "could not find text/calendar part";
-        return std::vector< Event >();
+        return std::vector<Event>();
     }
     return fromITip(Conversion::toStdString(QString::fromUtf8(c->decodedContent())));
 }
