@@ -55,7 +55,7 @@ void ObjectMoveJob::davJobFinished(KJob *job)
         return;
     }
 
-    auto *davJob = qobject_cast<KIO::DavJob *>(job);
+    auto davJob = qobject_cast<KIO::DavJob *>(job);
 
     const QDomDocument document = davJob->response();
 
