@@ -5,8 +5,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_FILESTORE_COLLECTIONMODIFYJOB_H
-#define AKONADI_FILESTORE_COLLECTIONMODIFYJOB_H
+#pragma once
 
 #include "job.h"
 
@@ -45,4 +44,3 @@ private:
 }
 }
 
-#endif
