@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_FILESTORE_ITEMFETCHJOB_H
-#define AKONADI_FILESTORE_ITEMFETCHJOB_H
+#pragma once
 
 #include "job.h"
 
@@ -64,4 +63,3 @@ private:
 }
 }
 
-#endif
