@@ -30,7 +30,7 @@ FileStore::AbstractJobSession::~AbstractJobSession()
 
 void FileStore::AbstractJobSession::notifyCollectionsReceived(FileStore::Job *job, const Collection::List &collections)
 {
-    auto *fetchJob = qobject_cast<FileStore::CollectionFetchJob *>(job);
+    auto fetchJob = qobject_cast<FileStore::CollectionFetchJob *>(job);
     if (fetchJob != nullptr) {
         fetchJob->handleCollectionsReceived(collections);
     }
@@ -38,7 +38,7 @@ void FileStore::AbstractJobSession::notifyCollectionsReceived(FileStore::Job *jo
 
 void FileStore::AbstractJobSession::notifyCollectionCreated(FileStore::Job *job, const Collection &collection)
 {
-    auto *createJob = qobject_cast<FileStore::CollectionCreateJob *>(job);
+    auto createJob = qobject_cast<FileStore::CollectionCreateJob *>(job);
     if (createJob != nullptr) {
         createJob->handleCollectionCreated(collection);
     }
@@ -46,7 +46,7 @@ void FileStore::AbstractJobSession::notifyCollectionCreated(FileStore::Job *job,
 
 void FileStore::AbstractJobSession::notifyCollectionDeleted(FileStore::Job *job, const Collection &collection)
 {
-    auto *deleteJob = qobject_cast<FileStore::CollectionDeleteJob *>(job);
+    auto deleteJob = qobject_cast<FileStore::CollectionDeleteJob *>(job);
     if (deleteJob != nullptr) {
         deleteJob->handleCollectionDeleted(collection);
     }
@@ -54,7 +54,7 @@ void FileStore::AbstractJobSession::notifyCollectionDeleted(FileStore::Job *job,
 
 void FileStore::AbstractJobSession::notifyCollectionModified(FileStore::Job *job, const Collection &collection)
 {
-    auto *modifyJob = qobject_cast<FileStore::CollectionModifyJob *>(job);
+    auto modifyJob = qobject_cast<FileStore::CollectionModifyJob *>(job);
     if (modifyJob != nullptr) {
         modifyJob->handleCollectionModified(collection);
     }
@@ -62,7 +62,7 @@ void FileStore::AbstractJobSession::notifyCollectionModified(FileStore::Job *job
 
 void FileStore::AbstractJobSession::notifyCollectionMoved(FileStore::Job *job, const Collection &collection)
 {
-    auto *moveJob = qobject_cast<FileStore::CollectionMoveJob *>(job);
+    auto moveJob = qobject_cast<FileStore::CollectionMoveJob *>(job);
     if (moveJob != nullptr) {
         moveJob->handleCollectionMoved(collection);
     }
@@ -70,7 +70,7 @@ void FileStore::AbstractJobSession::notifyCollectionMoved(FileStore::Job *job, c
 
 void FileStore::AbstractJobSession::notifyItemsReceived(FileStore::Job *job, const Item::List &items)
 {
-    auto *fetchJob = qobject_cast<FileStore::ItemFetchJob *>(job);
+    auto fetchJob = qobject_cast<FileStore::ItemFetchJob *>(job);
     if (fetchJob != nullptr) {
         fetchJob->handleItemsReceived(items);
     }
@@ -78,7 +78,7 @@ void FileStore::AbstractJobSession::notifyItemsReceived(FileStore::Job *job, con
 
 void FileStore::AbstractJobSession::notifyItemCreated(FileStore::Job *job, const Item &item)
 {
-    auto *createJob = qobject_cast<FileStore::ItemCreateJob *>(job);
+    auto createJob = qobject_cast<FileStore::ItemCreateJob *>(job);
     if (createJob != nullptr) {
         createJob->handleItemCreated(item);
     }
@@ -86,7 +86,7 @@ void FileStore::AbstractJobSession::notifyItemCreated(FileStore::Job *job, const
 
 void FileStore::AbstractJobSession::notifyItemModified(FileStore::Job *job, const Item &item)
 {
-    auto *modifyJob = qobject_cast<FileStore::ItemModifyJob *>(job);
+    auto modifyJob = qobject_cast<FileStore::ItemModifyJob *>(job);
     if (modifyJob != nullptr) {
         modifyJob->handleItemModified(item);
     }
@@ -94,7 +94,7 @@ void FileStore::AbstractJobSession::notifyItemModified(FileStore::Job *job, cons
 
 void FileStore::AbstractJobSession::notifyItemMoved(FileStore::Job *job, const Item &item)
 {
-    auto *moveJob = qobject_cast<FileStore::ItemMoveJob *>(job);
+    auto moveJob = qobject_cast<FileStore::ItemMoveJob *>(job);
     if (moveJob != nullptr) {
         moveJob->handleItemMoved(item);
     }
@@ -102,7 +102,7 @@ void FileStore::AbstractJobSession::notifyItemMoved(FileStore::Job *job, const I
 
 void FileStore::AbstractJobSession::notifyCollectionsChanged(FileStore::Job *job, const Collection::List &collections)
 {
-    auto *compactJob = qobject_cast<FileStore::StoreCompactJob *>(job);
+    auto compactJob = qobject_cast<FileStore::StoreCompactJob *>(job);
     if (compactJob != nullptr) {
         compactJob->handleCollectionsChanged(collections);
     }
@@ -110,7 +110,7 @@ void FileStore::AbstractJobSession::notifyCollectionsChanged(FileStore::Job *job
 
 void FileStore::AbstractJobSession::notifyItemsChanged(FileStore::Job *job, const Item::List &items)
 {
-    auto *compactJob = qobject_cast<FileStore::StoreCompactJob *>(job);
+    auto compactJob = qobject_cast<FileStore::StoreCompactJob *>(job);
     if (compactJob != nullptr) {
         compactJob->handleItemsChanged(items);
     }
