@@ -168,7 +168,7 @@ void SingleFileResourceBase::collectionChanged(const Akonadi::Collection &collec
 {
     const QString newName = collection.displayName();
     if (collection.hasAttribute<EntityDisplayAttribute>()) {
-        const auto *attr = collection.attribute<EntityDisplayAttribute>();
+        const auto attr = collection.attribute<EntityDisplayAttribute>();
         if (!attr->iconName().isEmpty()) {
             mCollectionIcon = attr->iconName();
         }
